@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.12';
+$Net::Kubernetes::VERSION = '0.13';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -64,7 +64,7 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespac
 
 <h2>Build Status</h2>
 
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.12" />
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.13" />
 
 =end html
 
@@ -186,4 +186,24 @@ L<Net::Kubernetes::Resource|Net::Kubernetes::Resource>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Christopher Pruden Dave Mueller
+
+=over 4
+
+=item *
+
+Christopher Pruden <cdpruden@liquidweb.com>
+
+=item *
+
+Dave <dave@perljedi.com>
+
+=item *
+
+Dave Mueller <dmueller@liquidweb.com>
+
+=back
+
 =cut
