@@ -10,7 +10,9 @@ my $kube = Net::Kubernetes->new(url=>'http://172.18.8.101:8080');
 
 my $ns = $kube->get_namespace('default');
 
-my $sec = $ns->build_secret('testing', { 'sshpubkeypub' => '/home/dave/.ssh/id_rsa.pub', 'otherthingjson' => {type=>'JSON', value=>{text=>'Ha Ha'}} });
+#my $sec = $ns->build_secret('testing', { 'sshpubkeypub' => '/home/dave/.ssh/id_rsa.pub', 'otherthingjson' => {type=>'JSON', value=>{text=>'Ha Ha'}} });
+
+print Dumper($ns->list_events())."\n";
 
 
 
